@@ -49,9 +49,11 @@ static gboolean motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 static gboolean button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data);
 static gboolean update_map (GtkWidget *w, gpointer data);
 static gboolean out_map (GtkWidget *w,GdkEventCrossing *event, gpointer data);
+static gboolean map (GtkWidget *widget, GdkEvent *event, gpointer data);
+static gboolean unmap (GtkWidget *widget, GdkEvent *event, gpointer data);
 
 ETzMap *
-e_tz_map_new (GstTimeTool *tool)
+e_tz_map_new (GstTool *tool)
 {
 	ETzMap *tzmap;
 	GPtrArray *locs;
@@ -73,15 +75,18 @@ e_tz_map_new (GstTimeTool *tool)
 	      GDK_LEAVE_NOTIFY_MASK | GDK_VISIBILITY_NOTIFY_MASK);
 	
 	locs = tz_get_locations (tzmap->tzdb);
-	
-	for (i = 0; g_ptr_array_index(locs, i); i++)
+
+	for (i = 0; i < locs->len; i++)
 	{
 		tzl = g_ptr_array_index (locs, i);
 		e_map_add_point (tzmap->map, NULL, tzl->longitude, tzl->latitude,
 				 TZ_MAP_POINT_NORMAL_RGBA);
 	}
-	
-	gtk_timeout_add (100, flash_selected_point, (gpointer) tzmap);
+
+	g_signal_connect (G_OBJECT (tzmap->map), "map-event",
+			  G_CALLBACK (map), tzmap);
+	g_signal_connect (G_OBJECT (tzmap->map), "unmap-event",
+			  G_CALLBACK (unmap), tzmap);
         g_signal_connect(G_OBJECT (tzmap->map), "motion-notify-event",
 			 G_CALLBACK (motion), (gpointer) tzmap);
 	g_signal_connect(G_OBJECT(tzmap->map), "button-press-event",
@@ -96,6 +101,29 @@ e_tz_map_new (GstTimeTool *tool)
 	return tzmap;
 }
 
+static gboolean
+map (GtkWidget *widget, GdkEvent *event, gpointer data)
+{
+	ETzMap *tzmap = (ETzMap *) data;
+
+	if (!tzmap->timeout_id)
+		tzmap->timeout_id = g_timeout_add (100, flash_selected_point, (gpointer) tzmap);
+
+	return FALSE;
+}
+
+static gboolean
+unmap (GtkWidget *widget, GdkEvent *event, gpointer data)
+{
+	ETzMap *tzmap = (ETzMap *) data;
+
+	if (tzmap->timeout_id) {
+		g_source_remove (tzmap->timeout_id);
+		tzmap->timeout_id = 0;
+	}
+
+	return FALSE;
+}
 
 TzDB *
 e_tz_map_get_tz_db (ETzMap *tzmap)
@@ -153,6 +181,8 @@ e_tz_map_set_location_text (ETzMap *tzmap, const gchar *name)
 		} else {
 			valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter);
 		}
+
+		g_free (location);
 	}
 }
 
@@ -165,18 +195,19 @@ e_tz_map_set_tz_from_name (ETzMap *tzmap, gchar *name)
 	double l_longitude = 0.0, l_latitude = 0.0;
 	int i;
 
+	g_return_if_fail (tzmap != NULL);
+
 	tz_db = e_tz_map_get_tz_db (tzmap);
 	locs = tz_get_locations (tz_db);
 
-	for (i = 0; i < locs->len; i++)
-	{
-		tz_loc = g_ptr_array_index (locs, i);
+	if (name) {
+		for (i = 0; i < locs->len; i++)	{
+			tz_loc = g_ptr_array_index (locs, i);
 
-		if (!strcmp(tz_location_get_zone(tz_loc), name))
-		{
-			tz_location_get_position (tz_loc,
-						  &l_longitude, &l_latitude);
-			break;
+			if (!strcmp(tz_location_get_zone(tz_loc), name)) {
+				tz_location_get_position (tz_loc, &l_longitude, &l_latitude);
+				break;
+			}
 		}
 	}
 
